@@ -27,14 +27,14 @@ class MenuItem(UserTestElementMixin):
         Default value: None.
 
     ``icon``
-        An optional string which contains name of icon from Font Awesome which
-        should be used for this menu item. Note that icons may not show on all
-        levels of menu.
+        An optional string which contains classes for icons from Font Awesome
+        which should be used for this menu item. Note that icons may not show
+        on all levels of menu. They are only supported at top level.
         Default value: None.
 
-    ``css_classes``
-        A list of css classes to be added to the menu item class attribute.
-        Default value: [].
+    ``css_styles``
+        String containing special CSS styling for this menu item.
+        Default value: None.
 
     ``description``
         An optional string that will be used as the ``title`` attribute of
@@ -46,10 +46,6 @@ class MenuItem(UserTestElementMixin):
         Disabled items are displayed but are not clickable.
         Default value: True.
 
-    ``template``
-        The template to use to render the menu item.
-        Default value: 'admin_tools/menu/item.html'.
-
     ``children``
         A list of children menu items. All children items must be instances of
         the ``MenuItem`` class.
@@ -59,10 +55,9 @@ class MenuItem(UserTestElementMixin):
     url = None
     add_url = None
     icon = None
-    css_classes = None
+    css_styles = None
     description = None
     enabled = True
-    template = 'wpadmin/menu/item.html'
     children = None
 
     def __init__(self, title=None, url=None, **kwargs):
@@ -77,11 +72,8 @@ class MenuItem(UserTestElementMixin):
             if hasattr(self.__class__, key):
                 setattr(self, key, kwargs[key])
         self.children = self.children or []
-        self.css_classes = self.css_classes or []
 
     def init_with_context(self, context):
-        """
-        """
         pass
 
     def is_selected(self, request):
@@ -107,6 +99,8 @@ class MenuItem(UserTestElementMixin):
 
 
 class AppList(AppListElementMixin, MenuItem):
+    """
+    """
 
     def __init__(self, title=None, models=None, exclude=None, **kwargs):
         self.models = list(models or [])
@@ -129,30 +123,34 @@ class AppList(AppListElementMixin, MenuItem):
                 }
             apps[app_label]['models'].append({
                 'title': capfirst(model._meta.verbose_name_plural),
-                'url': perms['change'] and self._get_admin_change_url(model,
-                                                                      context),
-                'add_url': perms['add'] and self._get_admin_add_url(model,
-                                                                    context),
-                'description': perms['change'] and _(u"Change")
-                    or _(u"No permission"),
+                'url': perms['change'] and self._get_admin_change_url(
+                    model, context),
+                'add_url': perms['add'] and self._get_admin_add_url(
+                    model, context),
+                'description':
+                # Translators: This is already translated in Django
+                perms['change'] and _("Change") 
+                # Translators: This is already translated in Django
+                or _("No permission"),
             })
 
-        apps_sorted = apps.keys()
+        apps_sorted = list(apps.keys())
         apps_sorted.sort()
-        for app in apps_sorted:
+        for app in sorted(apps.keys()):
             app_dict = apps[app]
-            item = MenuItem(title=app_dict['title'], url=app_dict['url'],
-                            description=app_dict['title'])
+            item = MenuItem(
+                title=app_dict['title'], url=app_dict['url'],
+                description=app_dict['title'])
             # sort model list alphabetically
-            apps[app]['models'].sort(lambda x, y: cmp(x['title'], y['title']))
+            apps[app]['models'].sort(key=lambda x: x['title'])
             for model_dict in apps[app]['models']:
-                model_item = MenuItem(**model_dict)
-                model_item.add_url = model_dict['add_url']
-                item.children.append(model_item)
+                item.children.append(MenuItem(**model_dict))
             self.children.append(item)
 
 
 class ModelList(AppListElementMixin, MenuItem):
+    """
+    """
 
     def __init__(self, title=None, models=None, exclude=None, **kwargs):
         self.models = list(models or [])
@@ -169,27 +167,13 @@ class ModelList(AppListElementMixin, MenuItem):
             title = capfirst(model._meta.verbose_name_plural)
             url = self._get_admin_change_url(model, context)
             add_url = self._get_admin_add_url(model, context)
-            item = MenuItem(title=title, url=url, description=title)
-            item.add_url = add_url
+            item = MenuItem(
+                title=title, url=url, description=title, add_url=add_url)
             self.children.append(item)
 
 
 class UserTools(MenuItem):
-
+    """
+    """
     is_user_tools = True
-    css_classes = ['float-right']
 
-
-# class Bookmarks(MenuItem, AppListElementMixin):
-#
-#    title = _('Bookmarks')
-#    icon = 'icon-bookmark'
-#    css_classes = ['float-right', 'bookmarks']
-#    is_bookmarks = True
-#
-#    def init_with_context(self, context):
-#
-#        from admin_tools.menu.models import Bookmark
-#
-#        for b in Bookmark.objects.filter(user=context['request'].user):
-#            self.children.append(MenuItem(mark_safe(b.title), b.url, is_bookmark=True))
